Home
last modified time | relevance | path

Searched refs:argument (Results 1 – 25 of 1277) sorted by relevance

12345678910>>...52

/llvm-project-15.0.7/llvm/test/MC/Mips/
H A Dmacro-aliases-invalid-wrong-error.s10 subu $4, $4, %lo($start) # O32: [[@LINE]]:{{[0-9]+}}: error: unexpected token in argument list
11 … # N64: [[@LINE-1]]:{{[0-9]+}}: error: unexpected token in argument list
12 subu $4, $4, $start # O32: [[@LINE]]:{{[0-9]+}}: error: unexpected token in argument list
13 … # N64: [[@LINE-1]]:{{[0-9]+}}: error: unexpected token in argument list
14 subu $4, $a4, $a4 # O32: [[@LINE]]:{{[0-9]+}}: error: unexpected token in argument list
15 subu $4, $4, %hi(end) # O32: [[@LINE]]:{{[0-9]+}}: error: unexpected token in argument list
16 … # N64: [[@LINE-1]]:{{[0-9]+}}: error: unexpected token in argument list
17 subu $4, $4, end + 4 # O32: [[@LINE]]:{{[0-9]+}}: error: unexpected token in argument list
19 subu $4, $4, end # O32: [[@LINE]]:{{[0-9]+}}: error: unexpected token in argument list
21 subu $4, $4, sp # O32: [[@LINE]]:{{[0-9]+}}: error: unexpected token in argument list
[all …]
/llvm-project-15.0.7/compiler-rt/lib/sanitizer_common/tests/
H A Dsanitizer_stoptheworld_test.cpp52 void *argument) { in Callback() argument
67 CallbackArgument argument; in TEST() local
72 StopTheWorld(&Callback, &argument); in TEST()
74 EXPECT_TRUE(argument.callback_executed); in TEST()
75 EXPECT_TRUE(argument.threads_stopped); in TEST()
114 void *argument) { in AdvancedCallback() argument
116 (AdvancedCallbackArgument *)argument; in AdvancedCallback()
134 AdvancedCallbackArgument argument; in TEST() local
138 argument.threads[0] = in TEST()
144 EXPECT_TRUE(argument.threads_stopped); in TEST()
[all …]
/llvm-project-15.0.7/clang/test/SemaOpenCL/
H A Dbuiltins-amdgcn-error-gfx908-param.cl23 …*out = __builtin_amdgcn_mfma_f32_32x32x1f32(a, b, c, d, 0, 0); // expected-error{{argument to '__b…
24 …*out = __builtin_amdgcn_mfma_f32_32x32x1f32(a, b, c, 0, d, 0); // expected-error{{argument to '__b…
25 …*out = __builtin_amdgcn_mfma_f32_32x32x1f32(a, b, c, 0, 0, d); // expected-error{{argument to '__b…
30 …*out = __builtin_amdgcn_mfma_f32_16x16x1f32(a, b, c, d, 0, 0); // expected-error{{argument to '__b…
31 …*out = __builtin_amdgcn_mfma_f32_16x16x1f32(a, b, c, 0, d, 0); // expected-error{{argument to '__b…
37 …*out = __builtin_amdgcn_mfma_f32_4x4x1f32(a, b, c, d, 0, 0); // expected-error{{argument to '__bui…
38 …*out = __builtin_amdgcn_mfma_f32_4x4x1f32(a, b, c, 0, d, 0); // expected-error{{argument to '__bui…
39 …*out = __builtin_amdgcn_mfma_f32_4x4x1f32(a, b, c, 0, 0, d); // expected-error{{argument to '__bui…
107 …*out = __builtin_amdgcn_mfma_i32_4x4x4i8(a, b, c, d, 0, 0); // expected-error{{argument to '__buil…
108 …*out = __builtin_amdgcn_mfma_i32_4x4x4i8(a, b, c, 0, d, 0); // expected-error{{argument to '__buil…
[all …]
H A Dbuiltins-amdgcn-error-gfx940-param.cl16 …*out = __builtin_amdgcn_mfma_i32_16x16x32_i8(a, b, c, d, 0, 0); // expected-error{{argument to '__…
17 …*out = __builtin_amdgcn_mfma_i32_16x16x32_i8(a, b, c, 0, d, 0); // expected-error{{argument to '__…
18 …*out = __builtin_amdgcn_mfma_i32_16x16x32_i8(a, b, c, 0, 0, d); // expected-error{{argument to '__…
23 …*out = __builtin_amdgcn_mfma_i32_32x32x16_i8(a, b, c, d, 0, 0); // expected-error{{argument to '__…
24 …*out = __builtin_amdgcn_mfma_i32_32x32x16_i8(a, b, c, 0, d, 0); // expected-error{{argument to '__…
25 …*out = __builtin_amdgcn_mfma_i32_32x32x16_i8(a, b, c, 0, 0, d); // expected-error{{argument to '__…
30 …*out = __builtin_amdgcn_mfma_f32_16x16x8_xf32(a, b, c, d, 0, 0); // expected-error{{argument to '_…
31 …*out = __builtin_amdgcn_mfma_f32_16x16x8_xf32(a, b, c, 0, d, 0); // expected-error{{argument to '_…
32 …*out = __builtin_amdgcn_mfma_f32_16x16x8_xf32(a, b, c, 0, 0, d); // expected-error{{argument to '_…
37 …*out = __builtin_amdgcn_mfma_f32_32x32x4_xf32(a, b, c, d, 0, 0); // expected-error{{argument to '_…
[all …]
H A Dprintf-format-strings.cl34 …mat specifies type 'double __attribute__((ext_vector_type(4)))' but the argument has type 'float4'…
35 …mat specifies type 'double __attribute__((ext_vector_type(4)))' but the argument has type 'half4' …
38 …mat specifies type 'double __attribute__((ext_vector_type(4)))' but the argument has type 'float4'…
39 …mat specifies type 'double __attribute__((ext_vector_type(4)))' but the argument has type 'half4' …
43 …mat specifies type 'double __attribute__((ext_vector_type(4)))' but the argument has type 'half4' …
47 …mat specifies type 'double __attribute__((ext_vector_type(4)))' but the argument has type 'half4' …
51 …mat specifies type 'double __attribute__((ext_vector_type(4)))' but the argument has type 'half4' …
90 … expected-warning {{double __attribute__((ext_vector_type(4)))' but the argument has type 'float4'…
93 … expected-warning {{double __attribute__((ext_vector_type(4)))' but the argument has type 'float4'…
120 …{{format specifies type 'int __attribute__((ext_vector_type(4)))' but the argument has type 'int'}}
[all …]
H A Dbuiltins-amdgcn-error-gfx90a-param.cl22 …*out = __builtin_amdgcn_mfma_f32_32x32x4bf16_1k(a, b, c, d, 0, 0); // expected-error{{argument to …
23 …*out = __builtin_amdgcn_mfma_f32_32x32x4bf16_1k(a, b, c, 0, d, 0); // expected-error{{argument to …
36 …*out = __builtin_amdgcn_mfma_f32_4x4x4bf16_1k(a, b, c, d, 0, 0); // expected-error{{argument to '_…
37 …*out = __builtin_amdgcn_mfma_f32_4x4x4bf16_1k(a, b, c, 0, d, 0); // expected-error{{argument to '_…
38 …*out = __builtin_amdgcn_mfma_f32_4x4x4bf16_1k(a, b, c, 0, 0, d); // expected-error{{argument to '_…
57 …*out = __builtin_amdgcn_mfma_f64_16x16x4f64(a, b, c, d, 0, 0); // expected-error{{argument to '__b…
58 …*out = __builtin_amdgcn_mfma_f64_16x16x4f64(a, b, c, 0, d, 0); // expected-error{{argument to '__b…
59 …*out = __builtin_amdgcn_mfma_f64_16x16x4f64(a, b, c, 0, 0, d); // expected-error{{argument to '__b…
64 …*out = __builtin_amdgcn_mfma_f64_4x4x4f64(a, b, c, d, 0, 0); // expected-error{{argument to '__bui…
65 …*out = __builtin_amdgcn_mfma_f64_4x4x4f64(a, b, c, 0, d, 0); // expected-error{{argument to '__bui…
[all …]
H A Dbuiltins-amdgcn-error.cl19 …__builtin_amdgcn_s_sleep(x); // expected-error {{argument to '__builtin_amdgcn_s_sleep' must be a …
24 …__builtin_amdgcn_s_waitcnt(x); // expected-error {{argument to '__builtin_amdgcn_s_waitcnt' must b…
29 …__builtin_amdgcn_s_sendmsg(in, 1); // expected-error {{argument to '__builtin_amdgcn_s_sendmsg' mu…
34 …__builtin_amdgcn_s_sendmsg(in1, in2); // expected-error {{argument to '__builtin_amdgcn_s_sendmsg'…
59 …__builtin_amdgcn_s_setprio(x); // expected-error {{argument to '__builtin_amdgcn_s_setprio' must b…
70 …*out = __builtin_amdgcn_sicmp(a, b, c); // expected-error {{argument to '__builtin_amdgcn_sicmp' m…
75 …*out = __builtin_amdgcn_uicmp(a, b, c); // expected-error {{argument to '__builtin_amdgcn_uicmp' m…
90 …*out = __builtin_amdgcn_fcmpf(a, b, c); // expected-error {{argument to '__builtin_amdgcn_fcmpf' m…
95 …*out = __builtin_amdgcn_fcmp(a, b, c); // expected-error {{argument to '__builtin_amdgcn_fcmp' mus…
155 …__builtin_amdgcn_s_setreg(x, 0); // expected-error {{argument to '__builtin_amdgcn_s_setreg' must …
[all …]
H A Dinvalid-pipe-builtin-cl2.0.cl12 read_pipe(tmp, p); // expected-error {{first argument to 'read_pipe' must be a pipe type}}
15 …read_pipe(p, tmp, tmp, ptr); // expected-error {{invalid argument type to function 'read_pipe' (…
17 …read_pipe(p, tmp); // expected-error {{invalid argument type to function 'read_pipe' (expecting …
24 …work_group_reserve_read_pipe(tmp, tmp); // expected-error{{first argument to 'work_group_reserv…
29 …commit_read_pipe(tmp, rid); // expected-error{{first argument to 'commit_read_pipe' must be a p…
41 write_pipe(tmp, p); // expected-error {{first argument to 'write_pipe' must be a pipe type}}
46 …write_pipe(p, tmp); // expected-error {{invalid argument type to function 'write_pipe' (expectin…
53 …work_group_reserve_write_pipe(tmp, tmp); // expected-error{{first argument to 'work_group_reser…
58 …commit_write_pipe(tmp, rid); // expected-error{{first argument to 'commit_write_pipe' must be a…
65 …get_pipe_num_packets(tmp); // expected-error {{first argument to 'get_pipe_num_packets' must be…
[all …]
H A Datomic-ops.cl27 …__opencl_atomic_init(I, 5); // expected-error {{address argument to atomic operation must be a poi…
32 …__opencl_atomic_store(0,0,0,0); // expected-error {{address argument to atomic builtin must be a p…
33 …__opencl_atomic_store((int *)0, 0, 0, 0); // expected-error {{address argument to atomic operation…
52 …ry_order_seq_cst, memory_scope_work_group); // expected-error {{address argument to atomic operati…
89 // non-integer memory order argument is casted to integer type.
99 …r_release, memory_scope_work_group); // expected-warning {{memory order argument to atomic operati…
100 …r_acq_rel, memory_scope_work_group); // expected-warning {{memory order argument to atomic operati…
104 …r_acquire, memory_scope_work_group); // expected-warning {{memory order argument to atomic operati…
106 …r_acq_rel, memory_scope_work_group); // expected-warning {{memory order argument to atomic operati…
161 …axed, memory_scope_work_item); // expected-error{{synchronization scope argument to atomic operati…
[all …]
/llvm-project-15.0.7/clang/test/SemaCXX/
H A Dwarn-memsize-comparison.cpp22 expected-note {{explicitly cast the argument}} in f()
28 expected-note {{explicitly cast the argument}} in f()
35 expected-note {{explicitly cast the argument}} in f()
41 expected-note {{explicitly cast the argument}} in f()
47 expected-note {{explicitly cast the argument}} in f()
53 expected-note {{explicitly cast the argument}} in f()
59 expected-note {{explicitly cast the argument}} in f()
66 expected-note {{explicitly cast the argument}} in f()
72 expected-note {{explicitly cast the argument}} in f()
78 expected-note {{explicitly cast the argument}} in f()
[all …]
/llvm-project-15.0.7/llvm/test/MC/Mips/mt/
H A Dmftr-mttr-aliases-invalid-wrong-error.s6 mftc0 0($4), $5 # CHECK: error: unexpected token in argument list
7 mftc0 0($4), $5, 1 # CHECK: error: unexpected token in argument list
8 mftgpr 0($4), $5 # CHECK: error: unexpected token in argument list
9 mftlo 0($3) # CHECK: error: unexpected token in argument list
10 mftlo 0($3), $ac1 # CHECK: error: unexpected token in argument list
11 mfthi 0($3) # CHECK: error: unexpected token in argument list
12 mfthi 0($3), $ac1 # CHECK: error: unexpected token in argument list
13 mftacx 0($3) # CHECK: error: unexpected token in argument list
14 mftacx 0($3), $ac1 # CHECK: error: unexpected token in argument list
15 mftdsp 0($4) # CHECK: error: unexpected token in argument list
[all …]
/llvm-project-15.0.7/clang-tools-extra/docs/clang-tidy/checks/bugprone/
H A Dargument-comment.rst1 .. title:: clang-tidy - bugprone-argument-comment
3 bugprone-argument-comment
6 Checks that argument comments match parameter names.
9 that are placed right before the argument.
33 When `true`, the check will ignore the single argument.
37 When `true`, the check will add argument comments in the format
58 When true, the check will add argument comments in the format
79 When true, the check will add argument comments in the format
100 When true, the check will add argument comments in the format
125 When true, the check will add argument comments in the format
[all …]
/llvm-project-15.0.7/clang/test/FixIt/
H A Dformat.m10 …printf("%s", x); // expected-warning{{format specifies type 'char *' but the argument has type 'in…
11 …printf("%lf", x); // expected-warning{{format specifies type 'double' but the argument has type 'i…
16 …NSLog(@"%s", x); // expected-warning{{format specifies type 'char *' but the argument has type 'in…
17 …NSLog(@"%lf", x); // expected-warning{{format specifies type 'double' but the argument has type 'i…
18 NSLog(@"%@", x); // expected-warning{{format specifies type 'id' but the argument has type 'int'}}
25 …printf("%d", x); // expected-warning{{format specifies type 'int' but the argument has type 'char …
31 …NSLog(@"%d", x); // expected-warning{{format specifies type 'int' but the argument has type 'char …
34 …NSLog(@"%@", x); // expected-warning{{format specifies type 'id' but the argument has type 'char *…
41 NSLog(@"%d", x); // expected-warning{{format specifies type 'int' but the argument has type 'id'}}
42 …NSLog(@"%s", x); // expected-warning{{format specifies type 'char *' but the argument has type 'id…
[all …]
H A Dformat-no-fixit.m12 printf("%d", x); // expected-warning{{format specifies type 'int' but the argument has type 'id'}}
13 …printf("%s", x); // expected-warning{{format specifies type 'char *' but the argument has type 'id…
14 …printf("%lf", x); // expected-warning{{format specifies type 'double' but the argument has type 'i…
26 …NSLog(@"%d", x); // expected-warning{{format specifies type 'int' but the argument has type 'CFStr…
27 …NSLog(@"%s", x); // expected-warning{{format specifies type 'char *' but the argument has type 'CF…
28 …NSLog(@"%lf", x); // expected-warning{{format specifies type 'double' but the argument has type 'C…
/llvm-project-15.0.7/compiler-rt/lib/lsan/
H A Dlsan_common_fuchsia.cpp69 CheckForLeaksParam *argument) { in LockStuffAndStopTheWorld() argument
75 CheckForLeaksParam *argument; in LockStuffAndStopTheWorld() member
76 } params = {{}, callback, argument}; in LockStuffAndStopTheWorld()
83 ScanGlobalRange(begin, end, &params->argument->frontier); in LockStuffAndStopTheWorld()
91 ScanRangeForPointers(begin, end, &params->argument->frontier, "STACK", in LockStuffAndStopTheWorld()
100 ScanRangeForPointers(begin, end, &params->argument->frontier, "REGISTERS", in LockStuffAndStopTheWorld()
124 &params->argument->frontier, "TLS", kReachable); in LockStuffAndStopTheWorld()
126 ScanRangeForPointers(begin2, end, &params->argument->frontier, "TLS", in LockStuffAndStopTheWorld()
129 ScanRangeForPointers(begin, end, &params->argument->frontier, "TLS", in LockStuffAndStopTheWorld()
154 &params->argument->frontier); in LockStuffAndStopTheWorld()
[all …]
/llvm-project-15.0.7/llvm/test/Transforms/Coroutines/
H A Dcoro-split-alloc.ll4 define i8* @f(i32 %argument) presplitcoroutine {
6 %argument.addr = alloca i32, align 4
7 %incremented = add i32 %argument, 1
8 store i32 %incremented, i32* %argument.addr, align 4
15 %allocator_argument = load i32, i32* %argument.addr, align 4
22 %print_argument = load i32, i32* %argument.addr, align 4
41 ; CHECK: %argument.addr = alloca i32
42 ; CHECK: %incremented = add i32 %argument, 1
43 ; CHECK-NEXT: store i32 %incremented, i32* %argument.addr
45 ; CHECK: %allocator_argument = load i32, i32* %argument.addr
[all …]
/llvm-project-15.0.7/llvm/test/Analysis/Lint/
H A Dnoalias-readonly.ll12 ; argument may depend on writes to the other.
13 ; CHECK: Unusual: noalias argument aliases another argument
25 ; the noalias argument may cause a dependency for the other.
26 ; CHECK: Unusual: noalias argument aliases another argument
39 ; CHECK-NOT: Unusual: noalias argument aliases another argument
/llvm-project-15.0.7/clang-tools-extra/test/clang-tidy/checkers/objc/
H A Dnsinvocation-argument-lifetime.m1 // RUN: %check_clang_tidy %s objc-nsinvocation-argument-lifetime %t
42 …y pass pointers to objects with ownership __unsafe_unretained [objc-nsinvocation-argument-lifetime]
45 …y pass pointers to objects with ownership __unsafe_unretained [objc-nsinvocation-argument-lifetime]
48 …y pass pointers to objects with ownership __unsafe_unretained [objc-nsinvocation-argument-lifetime]
51 …y pass pointers to objects with ownership __unsafe_unretained [objc-nsinvocation-argument-lifetime]
56 …y pass pointers to objects with ownership __unsafe_unretained [objc-nsinvocation-argument-lifetime]
62 …y pass pointers to objects with ownership __unsafe_unretained [objc-nsinvocation-argument-lifetime]
84 …y pass pointers to objects with ownership __unsafe_unretained [objc-nsinvocation-argument-lifetime]
86 …y pass pointers to objects with ownership __unsafe_unretained [objc-nsinvocation-argument-lifetime]
93 …y pass pointers to objects with ownership __unsafe_unretained [objc-nsinvocation-argument-lifetime]
[all …]
/llvm-project-15.0.7/clang/test/Analysis/
H A Dmig.mm196 … // expected-warning{{MIG callback fails with error after deallocating argument value}}
197 … // expected-note@-1{{MIG callback fails with error after deallocating argument value}}
204 … // expected-warning{{MIG callback fails with error after deallocating argument value}}
205 … // expected-note@-1{{MIG callback fails with error after deallocating argument value}}
211 … // expected-warning{{MIG callback fails with error after deallocating argument value}}
212 … // expected-note@-1{{MIG callback fails with error after deallocating argument value}}
218 …return KERN_ERROR; // expected-warning{{MIG callback fails with error after deallocating argument
219 // expected-note@-1{{MIG callback fails with error after deallocating argument value}}
243 … // expected-warning{{MIG callback fails with error after deallocating argument value}}
249 …ReturnError; // expected-warning{{MIG callback fails with error after deallocating argument value}}
[all …]
/llvm-project-15.0.7/clang/test/SemaObjC/
H A Dnonnull.m33 …nc1(0, cp2, i1); // expected-warning {{null passed to a callee that requires a non-null argument}}
34 …nc1(cp1, 0, i1); // expected-warning {{null passed to a callee that requires a non-null argument}}
38 …(0, i2, cp3, i3); // expected-warning {{null passed to a callee that requires a non-null argument}}
39 …cp3, i2, 0, i3); // expected-warning {{null passed to a callee that requires a non-null argument}}
41 func4(0, cp1); // expected-warning {{null passed to a callee that requires a non-null argument}}
42 func4(cp1, 0); // expected-warning {{null passed to a callee that requires a non-null argument}}
64 …eue_push_list(0); // expected-warning {{null passed to a callee that requires a non-null argument}}
94 …ingNotNull(NULL); // expected-warning {{null passed to a callee that requires a non-null argument}}
113 …sNullOnMethod:0]; // expected-warning {{null passed to a callee that requires a non-null argument}}
118 g(0); // expected-warning{{null passed to a callee that requires a non-null argument}}
[all …]
/llvm-project-15.0.7/llvm/test/Verifier/
H A Dreduction-intrinsics.ll3 ; Reject a vector reduction with a non-vector argument.
6 ; CHECK: Intrinsic has incorrect argument type!
12 ; CHECK: Intrinsic has incorrect argument type!
20 ; CHECK: Intrinsic has incorrect argument type!
33 ; We should have the appropriate (either int or FP) type of argument
37 ; CHECK: Intrinsic has incorrect argument type!
43 ; CHECK: Intrinsic has incorrect argument type!
49 ; CHECK: Intrinsic has incorrect argument type!
55 ; CHECK: Intrinsic has incorrect argument type!
H A Dallocsize.ll3 ; CHECK: 'allocsize' element size argument is out of bounds
6 ; CHECK: 'allocsize' element size argument must refer to an integer parameter
9 ; CHECK: 'allocsize' number of elements argument is out of bounds
12 ; CHECK: 'allocsize' number of elements argument must refer to an integer parameter
15 ; CHECK: 'allocsize' number of elements argument is out of bounds
/llvm-project-15.0.7/lldb/source/Commands/
H A DOptionsBase.td39 // Default value: OptionParser::eNoArgument (No argument allowed)
41 // - `OptionalArg`: Sets the argument type and marks it as optional.
42 // - `Arg`: Sets the argument type and marks it as required.
43 // - `EnumArg`: Sets the argument type to an enum and marks it as required.
81 // - `OptionalArg`: Sets the argument type and marks it as optional.
85 // - `Arg`: Sets the argument type and marks it as required.
96 // Use `OptionalEnumArg` for having an option enum argument.
142 // Gives the option an optional argument.
148 // Gives the option an required argument.
153 // Gives the option an required argument.
[all …]
/llvm-project-15.0.7/compiler-rt/lib/sanitizer_common/
H A Dsanitizer_stoptheworld_fuchsia.cpp27 void StopTheWorld(StopTheWorldCallback callback, void *argument) { in StopTheWorld() argument
30 void *argument; in StopTheWorld() member
31 } params = {callback, argument}; in StopTheWorld()
36 params->callback(SuspendedThreadsListFuchsia(), params->argument); in StopTheWorld()
/llvm-project-15.0.7/mlir/lib/CAPI/IR/
H A DPass.cpp95 ExternalPass(TypeID passID, StringRef name, StringRef argument, in ExternalPass() argument
99 : Pass(passID, opName), id(passID), name(name), argument(argument), in ExternalPass()
108 StringRef getArgument() const override { return argument; } in getArgument()
138 return std::make_unique<ExternalPass>(id, name, argument, description, in clonePass()
146 std::string argument; member in mlir::ExternalPass
155 MlirStringRef argument, in mlirCreateExternalPass() argument
162 unwrap(passID), unwrap(name), unwrap(argument), unwrap(description), in mlirCreateExternalPass()

12345678910>>...52